#ifndef _SHOEHORN_TARGET_H
#define _SHOEHORN_TARGET_H

#if defined(WIN32)
#include <windows.h>
#endif

#if !defined(strcasecmp) && defined(WIN32)
#define strcasecmp stricmp
#endif

#if !defined(sleep) && defined(WIN32)
#define sleep(time) Sleep(time * 1000)
#endif

#if !defined(usleep) && defined(WIN32)
#define usleep(time) Sleep((time ? (time/1000)+1 : 0))
#endif 

typedef enum _script_label_e{
  sl_DRAM_START = 1,
  sl_INITRD_START,
  sl_KERNEL_OFFSET,
  sl_SRAM_SIZE,

  sl_READB,
  sl_READW,
  sl_READ,
  sl_WRITEB,
  sl_WRITEW,
  sl_WRITE,

  sl_PUTC,

  sl_OR,
  sl_AND,

  sl_IF,
  sl_ENDIF,

  sl_PRINT,
  sl_PRINTBUF,
  sl_SLEEP,

  sl_SERIAL_BAUD,
}script_label_e;

#define LINEINFO_BUFSIZE 256
struct line_info{
  int label;
  unsigned long addr;
  unsigned long value;
  char buf[LINEINFO_BUFSIZE];
  int internal_buf;
};
  
struct script_cmd_info{
  int label;
  char *name;
  int (*func)(char*,struct line_info*);
};


int execute_script(FILE *fp, int fake);
unsigned long get_initrd_start(FILE *fp);
unsigned long get_dram_start(FILE *fp);
unsigned long get_kernel_offset(FILE *fp);
unsigned long get_sram_size(FILE *fp);



#endif
